%define major   6
%define libname %mklibname cryptopp %{major}

Name:           libcryptopp
Version:        5.6.2
Release:        %mkrel 2
Summary:        Public domain C++ class library of cryptographic schemes
License:        Public Domain
Group:          System/Libraries
URL:            http://www.cryptopp.com/
Source0:        http://www.cryptopp.com/cryptopp562.zip
Source1:		cryptopp.pc
Patch0:			cryptopp-5.6.2-autotools.patch
Patch1:			cryptopp-5.6.2-data-files-location.patch
Patch2:			cryptopp-5.6.2-x86-disable-sse2.patch
BuildRequires:  doxygen
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
Crypto++ Library is a public domain C++ class library of cryptographic 
schemes. Currently the library consists of the following features:

    * a class hierarchy with an API defined by abstract base classes 
    * AES(Rijndael) and AES candidates: RC6, MARS, Twofish, Serpent, 
      CAST-256
    * other symmetric block ciphers: IDEA, DES, Triple-DES (DES-EDE2 
      and DES-EDE3), DESX (DES-XEX3), RC2, RC5, Blowfish, TEA, XTEA, 
      SAFER, 3-WAY, GOST, SHARK, CAST-128, Square, Skipjack, Camellia, 
      SHACAL-2
    * generic block cipher modes: ECB, CBC, CBC ciphertext stealing 
      (CTS), CFB, OFB, counter mode (CTR)
    * stream ciphers: Salsa20, Panama, ARC4, SEAL, WAKE, WAKE-OFB, 
      BlumBlumShub
    * public-key cryptography: RSA, DSA, ElGamal, Nyberg-Rueppel (NR),
      Rabin, Rabin-Williams (RW), LUC, LUCELG, DLIES (variants of 
      DHAES), ESIGN
    * padding schemes for public-key systems: PKCS#1 v2.0, OAEP, PSS, 
      PSSR, IEEE P1363 EMSA2 and EMSA5
    * key agreement schemes: Diffie-Hellman (DH), Unified
      Diffie-Hellman (DH2), Menezes-Qu-Vanstone (MQV), LUCDIF, XTR-DH
    * elliptic curve cryptography: ECDSA, ECNR, ECIES, ECDH, ECMQV
    * one-way hash functions: SHA-1, MD2, MD4, MD5, HAVAL, RIPEMD-128, 
      RIPEMD-256, RIPEMD-160, RIPEMD-320, Tiger, SHA-2 (SHA-224, 
      SHA-256, SHA-384, and SHA-512), Panama, WHIRLPOOL
    * message authentication codes: MD5-MAC, HMAC, XOR-MAC, CBC-MAC, 
      DMAC, Two-Track-MAC
    * cipher constructions based on hash functions: Luby-Rackoff, MDC
    * pseudo random number generators (PRNG): ANSI X9.17 appendix C, 
      PGP's RandPool
    * password based key derivation functions: PBKDF1 and PBKDF2 from 
      PKCS #5
    * Shamir's secret sharing scheme and Rabin's information dispersal 
      algorithm (IDA)
    * DEFLATE (RFC 1951) compression/decompression with gzip (RFC 
      1952) and zlib (RFC 1950) format support
    * fast multi-precision integer (bignum) and polynomial operations, 
      with SSE2 optimizations for Pentium 4 processors, and support for 
      64-bit CPUs
    * finite field arithmetics, including GF(p) and GF(2^n)
    * prime number generation and verification
    * various miscellaneous modules such as base 64 coding and 32-bit 
      CRC
    * class wrappers for these operating system features (optional):
          o high resolution timers on Windows, Unix, and MacOS
          o Berkeley and Windows style sockets
          o Windows named pipes
          o /dev/random, /dev/urandom, /dev/srandom
          o Microsoft's CryptGenRandom on Windows 
    * A high level interface for most of the above, using a 
      filter/pipeline metaphor
    * benchmarks and validation testing
    * FIPS 140-2 Validated 

Because one purpose of the project is to act as a repository of public 
domain (not copyrighted) cryptographic source code, the code in 
Crypto++ was either written specifically for this project by its 
contributors and placed in the public domain, or derived from other 
sources that are public domain (again with the exception of mars.cpp).

%package -n %{libname}
Group:          System/Libraries
Summary:        Base shared library part of %{name}
Obsoletes:      %{name} < %{version}-%{release}
Provides:       %{name} = %{version}-%{release}

%description -n %libname
Crypto++ Library is a free C++ class library of cryptographic schemes.

This package contains the library needed to run programs dynamically
linked with %{name}.

%package -n %{libname}-devel
Summary:        Header files and development documentation for %{name}
Group:          Development/Libraries
Requires:       %{libname} = %{version}-%{release}
Obsoletes:      %{name}-devel < %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       %{_lib}cryptopp-devel = %{version}-%{release}
Provides:       cryptopp-devel = %{version}-%{release}
Obsoletes: 	%{libname}-static-devel

%description -n %{libname}-devel
Crypto++ Library is a free C++ class library of cryptographic schemes.

This package contains the header files and development documentation
for %{name}.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation
Provides:       cryptopp-doc = %{version}-%{release}

%description doc
Crypto++ Library is a free C++ class library of cryptographic schemes.

This package contains documentation for %{name}.

%package progs
Summary:        Programs for manipulating %{name} routines
Group:          Development/Other
Provides:       cryptopp-progs = %{version}-%{release}

%description progs
Crypto++ Library is a free C++ class library of cryptographic schemes.

This package contains programs for manipulating %{name} routines.

%prep
%setup -q -c
%apply_patches


rm -f GNUmakefile

perl -pi -e 's/\r$//g' License.txt Readme.txt

%build
autoreconf -fiv
%configure2_5x --disable-static
%make


%install
rm -rf %{buildroot}
%makeinstall_std

#we don't want these
find %{buildroot} -name '*.la' -delete

# Install the pkg-config file
install -D -m644 %{SOURCE1} %{buildroot}%{_libdir}/pkgconfig/cryptopp.pc

# Fill in the variables
sed -i "s|@PREFIX@|%{_prefix}|g" %{buildroot}%{_libdir}/pkgconfig/cryptopp.pc
sed -i "s|@LIBDIR@|%{_libdir}|g" %{buildroot}%{_libdir}/pkgconfig/cryptopp.pc
sed -i "s|@INCLUDEDIR@|%{_includedir}|g" %{buildroot}%{_libdir}/pkgconfig/cryptopp.pc

mkdir -p %{buildroot}%{_datadir}/%{name}/TestVectors
mkdir -p %{buildroot}%{_datadir}/%{name}/TestData
install -m644 TestVectors/* %{buildroot}%{_datadir}/%{name}/TestVectors
install -m644 TestData/* %{buildroot}%{_datadir}/%{name}/TestData

rm -f %{buildroot}%{_bindir}/cryptestcwd

ln -s %{_libdir}/libcryptopp.so.6.0.0 %{buildroot}/%{_libdir}/libcrypto++.so.9
ln -s %{_libdir}/libcryptopp.so.6.0.0 %{buildroot}/%{_libdir}/libcryptopp-5.6.2.so.0

%clean
rm -rf %{buildroot}


%files -n %{libname}
%defattr(0644,root,root,0755)
%doc License.txt Readme.txt
%defattr(-,root,root,0755)
%{_libdir}/*.so.*
%{_libdir}/libcrypto++.so.9

%files -n %{libname}-devel
%defattr(0644,root,root,0755)
%{_includedir}/cryptopp
%defattr(-,root,root,0755)
%{_libdir}/*.so
%{_libdir}/pkgconfig/cryptopp.pc


%files doc
%defattr(0644,root,root,0755)
%doc

%files progs
%defattr(0644,root,root,0755)
%attr(0755,root,root) %{_bindir}/cryptest
%{_datadir}/libcryptopp


%changelog
* Wed Jun 15 2016 bb <bb> 5.6.2-1pclos2016
- rebuild for 2016
- add synlink libcryptopp-5.6.2.so.0 so
- megasync will work

* Sat Sep 06 2014 bb <bb> 5.6.2-1pclos2014
- update 5.6.2
- drop la files
- drop static build
